@@ -1,11 +1,11 @@
 from .main import (
-	get, is_loaded, load_config, environment, debug
+	get, is_loaded, load, environment, debug
 )
 from .constants import (DOT_ENV_FILE, LOCAL_CONFIG_FILE_PREFIX, ENVIRONMENT_VARIABLE_NAME, DEBUG_VARIABLE_NAME,
                         DEBUG_VARIABLE_VALUE, PYENV_LOAD_STATUS_KEY)
 
 __all__ = [
-	"get", "is_loaded", "load_config", "environment", "debug",
+	"get", "is_loaded", "load", "environment", "debug",
 	"DOT_ENV_FILE",
 	"LOCAL_CONFIG_FILE_PREFIX",
 	"ENVIRONMENT_VARIABLE_NAME",
